@@ -1,3 +1,6 @@
+
+import warnings
+warnings.filterwarnings("ignore", "apt API not stable yet", FutureWarning)
 import apt
 import apt_pkg
 
@@ -33,7 +36,8 @@ class LanguageSelectorPkgCache(apt.Cache):
         ("firefox", "mozilla-firefox-locale-"),
         ("mozilla-thunderbird", "mozilla-thunderbird-local-"),
         ("openoffice.org", "openoffice.org-l10n-"),
-        ("openoffice.org", "openoffice.org-help-")
+        ("openoffice.org", "openoffice.org-help-"),
+        ("libsword5c2a", "sword-language-pack-")
     ]
 
 
@@ -45,6 +49,10 @@ class LanguageSelectorPkgCache(apt.Cache):
         # keep the lists 
         self.to_inst = []
         self.to_rm = []
+
+    def clear(self):
+        """ clear the selections """
+        self._depcache.Init()
         
     def getChangesList(self):
         to_inst = []
