@@ -3,6 +3,7 @@
 # a helper class to get locale info
 
 import string
+import re            
 import subprocess
 
 from gettext import gettext as _
@@ -47,6 +48,11 @@ class LocaleInfo(object):
             if tmp.startswith("#") or tmp == "":
                 continue
             w = tmp.split(";")
+            # FIXME: the latest localechoosers "languagelist" does
+            # no longer have this field for most languages, so
+            # deal with it and don't set LANGUAGE then
+            # - the interessting question is what to do
+            # if LANGUAGE is already set and the new
             localeenv = w[6].split(":")
             #print localeenv
             self._languagelist[localeenv[0]] = '%s' % w[6]
@@ -87,12 +93,16 @@ class LocaleInfo(object):
             (lang, country) = string.split(locale, "_")
             # get all locales for this language
             l = filter(lambda k: k.startswith(lang+"_"), self.generated_locales())
-            # only show region/county if we have more than one 
+            # only show region/country if we have more than one 
             if len(l) > 1:
-                return "%s (%s)" % (_(self.lang(lang)), _(self.country(country)))
+                mycountry = self.country(country)
+                if mycountry:
+                    return "%s (%s)" % (_(self.lang(lang)), _(mycountry))
+                else:
+                    return "%s" % (_(self.lang(lang)))
             else:
-                return self.lang(lang)
-        return self.lang(locale)
+                return _(self.lang(lang))
+        return _(self.lang(locale))
 
     def makeEnvString(self, code):
         """ input is a language code, output a string that can be put in
@@ -116,6 +126,10 @@ class LocaleInfo(object):
                 (key,value) = line.split("=")
                 value = value.strip('"')
                 return value.split(":")[0]
+        for line in open(self.environment).readlines():
+            match = re.match(r'LANG="([a-zA-Z_]*).*"$',line)
+            if match:
+                return match.group(1)
 
 if __name__ == "__main__":
     datadir = "/usr/share/language-selector/"
@@ -123,7 +137,7 @@ if __name__ == "__main__":
                     "%s/data/countries" % datadir,
                     "%s/data/languagelist" % datadir)
 
-    print li.getDefaultLanguage()
+    print "default: '%s'" % li.getDefaultLanguage()
 
     print li._lang
     print li._country
